% field to plot (vx=1,vy=2,vz=3,rho=4,wx=5,wy=6,wz=7)
type_field=7;

% ######################
% on touche plus
% ######################

if strcmp('PCWIN', computer)
	system('dir /O-D /AD /B .');
else
	system('ls -t .');
end

name_file = input('\nFichier de vitesse a representer: ', 's');


% On determine si les fichiers sont ecrits en little-endian ou en big-endian

% on commence par essayer en little-endian (PC)
type_endian = 'ieee-le';
FID = fopen(name_file, 'r',type_endian);
poub = fread(FID, 1, 'integer*4');
flag = fread(FID, 1, 'integer*4');
status = fclose(FID);

% si le flag est different de 1, on essaye le big-endian (SGI, NEC, IBM)
if flag ~= 1
    type_endian = 'ieee-be';
    FID = fopen(name_file, 'r',type_endian);
    poub = fread(FID, 1, 'integer*4');
    flag = fread(FID, 1, 'integer*4');
    status = fclose(FID);

    % on verifie que le flag vaut bien 1 cette fois-ci
    if flag ~= 1
        fprintf(1, '\n Il y a un probleme dans le format du fichier : le flag est different de 1\n');
        return
    end
end


% on lit toutes les metadonnees
FID = fopen(name_file, 'r',type_endian);

poub            = fread(FID, 1, 'integer*4');
flag            = fread(FID, 1, 'integer*4');
nx              = fread(FID, 1, 'integer*4');
ny              = fread(FID, 1, 'integer*4');
nz              = fread(FID, 1, 'integer*4');
lx              = fread(FID, 1, 'real*8');
ly              = fread(FID, 1, 'real*8');
lz              = fread(FID, 1, 'real*8');
dt              = fread(FID, 1, 'real*8');
truncate        = fread(FID, 1, 'integer*4');
type_trunc      = fread(FID, 1, 'integer*4');
rtrunc_x        = fread(FID, 1, 'real*8');
rtrunc_y        = fread(FID, 1, 'real*8');
rtrunc_z        = fread(FID, 1, 'real*8');
nu              = fread(FID, 1, 'real*8');
stratification  = fread(FID, 1, 'integer*4');
xns             = fread(FID, 1, 'real*8');
schm            = fread(FID, 1, 'real*8');
omega2          = fread(FID, 1, 'real*8');
perturb         = fread(FID, 1, 'integer*4');
lin             = fread(FID, 1, 'integer*4');
poub            = fread(FID, 1, 'integer*4');

poub            = fread(FID, 1, 'integer*4');
instant         = fread(FID, 1, 'real*8');
status = fclose(FID);


% on affiche quelques informations sur la simulation
fprintf(1, '\n Dimensions du probleme: %i * %i * %i \n', nx, ny, nz);
fprintf(1, '\n Dimensions physiques de la boite: %f * %f * %f \n', lx, ly, lz);

if (stratification == 0)
    freq_brunt = 0;
else
    freq_brunt = xns;
end

fprintf(1, '\n Stratification: %f \n', freq_brunt);

if (perturb==0)
    texte = ['non perturbatif'];
else
    if (lin==0) then
        texte = ['perturbatif/non lineaire'];
    else
        texte = ['perturbatif/lineaire'];
    end
end


% on cre la grille des points de colocation
X = linspace(0, lx-lx/nx, nx);
Y = linspace(0, ly-ly/ny, ny);
Z = linspace(0, lz-lz/nz, nz);

% on demande quel plan representer
iz = floor(input('\nPlan de coupe: '));

% on lit les donnees correspondant au plan choisi
FID = fopen(name_file, 'r',type_endian);
fseek(FID,33*4 + (4+8+4) + (type_field-1)*(4+8*nx*ny*nz+4) + 4 + 8*(iz-1)*nx*ny, 'bof');
Vort_Z_iz = fread(FID, nx*ny, 'real*8');
status = fclose(FID);

Vort_Z_iz = reshape(Vort_Z_iz, [nx,ny]);

% on lit la vorticite verticale de l etat de base
FID = fopen(name_file, 'r',type_endian);
fseek(FID,33*4 + (4+8+4) + 7*(4+8*nx*ny*nz+4) + 4 + 3*8*nx*ny + 4 + 4 + 2*(8*nx*ny), 'bof');
WBZ = fread(FID, nx*ny, 'real*8');
status = fclose(FID);

WBZ = reshape(WBZ, [nx,ny]);

figure

% on definit la nouvelle colormap
cm(1,:)=[0.8 0.8 0.8];
cm(2,:)=[1 1 1];
colormap(cm);

% on periodise l'ecoulement
X_new = [X,X+lx];
Vort_Z_iz_new = [Vort_Z_iz;Vort_Z_iz];
%X_new = X;
%Vort_Z_iz_new = Vort_Z_iz;

level=max(max(Vort_Z_iz_new))*[1,0.75,0.55,0.35,0.15,-1,-0.75,-0.55,-0.35,-0.15];

contourf(X_new,Y,-Vort_Z_iz_new',level);
axis equal tight   
axis([0,X(end),10,28])
hold on;

X_new = [X,X+lx];
WBZ_new = [WBZ;WBZ];
%WBZ_new = WBZ;
contour(X_new, Y, WBZ_new', max(max(WBZ))*[-0.0183; 0.0183],'b--')
xlabel('x');
ylabel('y');
axis equal tight;
title({['Field  t=', num2str(instant)]; ['Nb_points=', num2str(nx), 'x', num2str(ny), 'x', num2str(nz), '  L=', num2str(lx), 'x', num2str(ly), 'x', num2str(lz), '  dt=',num2str(dt), '  nu=',num2str(nu),'  N=', num2str(freq_brunt), '  ', texte]},'Interpreter','none');
