% ce script permet de lire les resultats des derivees par rapport  z de u, v et b: dudz, dvdz et dbdz
% on peut ensuite calculer un nombre de Richardson et voir si l'coulement est KH instable
% on peut aussi voir si l'coulement est statiquement stable ou instable selon le signe de 1-db/dz

% type de graphique que l'on veut tracer
type_graphique=2

%%%%%%%%%%%%%%%%%%%%%
% On ne touche plus
%%%%%%%%%%%%%%%%%%%%%

if strcmp('PCWIN', computer)
	ls('.');
else
	system(['ls -t ', '.']);
end

fichier = input('Dissipation field file to use: ', 's');


% on commence par essayer en little-endian (PC)
type_endian = 'ieee-le';
FID = fopen(fichier, 'r',type_endian);
poub = fread(FID, 1, 'integer*4');
flag = fread(FID, 1, 'integer*4');
status = fclose(FID);

% si le flag est different de 1, on essaye le big-endian (SGI, NEC, IBM)
if flag ~= 1
    type_endian = 'ieee-be';
    FID = fopen(fichier, 'r',type_endian);
    poub = fread(FID, 1, 'integer*4');
    flag = fread(FID, 1, 'integer*4');
    status = fclose(FID);

    % on verifie que le flag vaut bien 1 cette fois-ci
    if flag ~= 1
        fprintf(1, '\n Il y a un probleme dans le format du fichier : le flag est different de 1\n');
        return
    end
end

% on lit toutes les metadonnees
FID = fopen(fichier, 'r',type_endian);

poub            = fread(FID, 1, 'integer*4');
flag            = fread(FID, 1, 'integer*4');
nx              = fread(FID, 1, 'integer*4');
ny              = fread(FID, 1, 'integer*4');
nz              = fread(FID, 1, 'integer*4');
lx              = fread(FID, 1, 'real*8');
ly              = fread(FID, 1, 'real*8');
lz              = fread(FID, 1, 'real*8');
nu              = fread(FID, 1, 'real*8');
xnsqr           = fread(FID, 1, 'real*8');
poub            = fread(FID, 1, 'integer*4');

poub            = fread(FID, 1, 'integer*4');
instant         = fread(FID, 1, 'real*8');
poub            = fread(FID, 1, 'integer*4');

status = fclose(FID);

% on cre la grille des points de colocation
X = linspace(0, lx-lx/nx, nx);
Y = linspace(0, ly-ly/ny, ny);
Z = linspace(0, lz-lz/nz, nz);


% on demande quel plan representer
ny0 = floor(input('\nPlan de coupe: '));

fprintf(1, '      Reading...');
FID = fopen(fichier,'r',type_endian);



% on lit toutes les metadonnees d'un coup
fseek(FID, 4*17, 'bof');
instant = fread(FID, 1, 'real*8');


% on va directement lire le champ en n'enregistrant que les valeurs appartenant au plan xz voulu
field = zeros(nx,nz);
for iz=1:nz
    type_field=1;
	fseek(FID,16*4 + (4+8+4) + (type_field-1)*(4+8*nx*ny*nz+4) + 4 + 8*(iz-1)*nx*ny + 8*nx*(ny0-1), 'bof');
	dudz(:,iz) = fread(FID, nx, 'real*8');
	
	type_field=2;
	fseek(FID,16*4 + (4+8+4) + (type_field-1)*(4+8*nx*ny*nz+4) + 4 + 8*(iz-1)*nx*ny + 8*nx*(ny0-1), 'bof');
	dvdz(:,iz) = fread(FID, nx, 'real*8');
	
	type_field=3;
	fseek(FID,16*4 + (4+8+4) + (type_field-1)*(4+8*nx*ny*nz+4) + 4 + 8*(iz-1)*nx*ny + 8*nx*(ny0-1), 'bof');
	drhodz(:,iz) = fread(FID, nx, 'real*8');
end


% On calcule Ri
Rix = xnsqr*dudz.^(-2);
Riy = xnsqr*dvdz.^(-2);
Rit = xnsqr*(dudz.^2+dvdz.^2).^-1;

fprintf(1, '\n      Plotting...\n');
if type_graphique==1
    figure
    contourf(X,Z,min(Rit,1)');
	axis equal tight
	title(['min(Ri_T,1)   t=', num2str(instant)]);    
	colorbar;
    
    figure
    contourf(X,Z,(1-drhodz)');
	axis equal tight
    colorbar;
	title(['1-db/dz   t=', num2str(instant)]);
else
    figure(1)
    pcolor(X,Z,Rit');
	axis equal tight    
	title(['min(Ri_T,1)   t=', num2str(instant)]);
    shading interp
	hold on
	contour(X,Z,Rit',0.25,'r');
	caxis([0 1]);
    colorbar;
	hold off

    figure(2)
    pcolor(X,Z,(1-drhodz)');
	axis equal tight    
	title(['1-db/dz   t=', num2str(instant)]);
    shading interp
	hold on
	contour(X,Z,Rit',0.25,'k');
	caxis([-1 1]);
	colorbar;
	hold off
end
