# @ job_name = rawdata
# @ shell = /bin/ksh
# @ output = $(job_name).$(jobid)
# @ error =  $(job_name).$(jobid)
# @ cpu_limit = 1:00:00
# @ data_limit = 4Gb
# @ queue

# we indicate where the velocity files are stores on gaya
dir_save_gaya="/u/rech/bll/rbll200/pair_counter_rotating_vortices_nonlinear/box_2.1x2.1/Fh1.33_Re6000/ns3d_contrarotating_384x384x96_L=2.1x2.1x0.57_Dt=0.0025_nu=0.0001_N=12._brodie_13-12-06_23h25_pid12836"

# dimensions of the velocity files and the strides along each directions
nx=384
ny=384
nz=96

# which field we want to extract? (vx=1,vy=2,vz=3,rho=4,wx=5,wy=6,wz=7)
type_field=1


#____________________________________________________________
#
#     DO NOT MODIFY BELOW!
#____________________________________________________________
#

printf "\nTemp directory: $TMPDIR\n"
cp rawdata.F90 $TMPDIR

cd $TMPDIR

# we change the dimensions in the source file
sed -e "s/integer, parameter :: nx=.*/integer, parameter :: nx=$nx/" \
    -e "s/integer, parameter :: ny=.*/integer, parameter :: ny=$ny/" \
    -e "s/integer, parameter :: nz=.*/integer, parameter :: nz=$nz/" \
    -e "s/integer :: type_field=.*/integer :: type_field=$type_field/" \
    rawdata.F90 > rawdata.F90_bis

mv rawdata.F90_bis rawdata.F90

# compilation
printf "\nCompilation of the Fortran code...\n"
xlf_r -qfree=F90 -qsuffix=f=F90 -qintsize=8 rawdata.F90 -o rawdata.out
chmod 744 rawdata.out


# we get the list of the original velocity files
printf "\nGetting the list of the original files from Gaya...\n"
ssh -x rbll200@gaya.idris.fr "cd $dir_save_gaya ; ls -1 velo_rho_vort.t=000{8,9}.{0,5}00 > liste_fichiers.txt"
mfget        $dir_save_gaya/liste_fichiers.txt .

# we create the save directory on gaya
printf "\nCreation of the save directory on Gaya...\n"
ssh -x rbll200@gaya.idris.fr "mkdir -p $dir_save_gaya/rawdata_${nx}x${ny}x${nz}"

# Copy of each file...
printf "\nCopy of the files and creating rawdata...\n"
for name in `cat liste_fichiers.txt`; do
	mfget	$dir_save_gaya/$name;
	echo $name | ./rawdata.out;
	mfput *.raw $dir_save_gaya/rawdata_${nx}x${ny}x${nz};
	rm -rf $name *.raw ;
done

mfput rawdata.F90 rawdata.out liste_fichiers.txt $dir_save_gaya/rawdata_${nx}x${ny}x${nz}

exit
