% ######################
% global_vars a renseigner
% ######################

% dossier de depart dans lequel on va regarder...
dir_base ='.';

% on choisit si on veut afficher :
%   1) le mode global au dernier instant enregistre
%   2) le mode kz par kz au dernier instant enregistre
%   3) on trace quelques kz indiques dans un tableau ci-dessous (non fonctionnel encore)
mode_affichage = 3;

% liste des indices des kz que l'on veut tracer dans le mode_affichage=3
liste_kz = [6,9,12,14];

% On choisit si on utilise dans les differents graphiques
%   1) la fonction contour. Trace plus joli mais plus long.
%   2) la fonction pcolor. Trac rapide en particulier s'il n'y a pas de structure mais grossier 
type_graphique = 2;

% nombre de graphiques par figure
subplot_par_figure = [2,2];


% ######################
% on touche plus
% ######################

fprintf(1, '\nRepertoire de depart : %s\n\n', dir_base);

if strcmp('PCWIN', computer)
	system(['dir /O-D /AD /B ', dir_base]);
else
	system(['ls -t ', dir_base]);
end

dir_spec = input('\nRepertoire specifique: ', 's');

dir_complet = [dir_base,'/',dir_spec,'/'];


% noms des fichiers de donnees
if strcmp('PCWIN', computer)
	[poub,liste_fichiers] = system(['dir /B "', dir_complet, '"']);
else
	[poub,liste_fichiers] = system(['ls ', dir_complet]);	
end

[start,finish] = regexpi(liste_fichiers,'velo_rho_vort.t=\d*\.\d*');

nb_fichiers = size(start,2);

clear nom_fichier
for i=1:nb_fichiers
    nom_fichier(i,:) = liste_fichiers(start(i):finish(i));
end

nom_fichier = sortrows(nom_fichier);

% On determine si les fichiers sont ecrits en little-endian ou en big-endian

% on commence par essayer en little-endian (PC)
type_endian = 'ieee-le';
FID = fopen([dir_complet,'/',nom_fichier(1,:)], 'r',type_endian);
poub = fread(FID, 1, 'integer*4');
flag = fread(FID, 1, 'integer*4');
status = fclose(FID);

% si le flag est different de 1, on essaye le big-endian (SGI, NEC, IBM)
if flag ~= 1
    type_endian = 'ieee-be';
    FID = fopen([dir_complet,'/',nom_fichier(1,:)], 'r',type_endian);
    poub = fread(FID, 1, 'integer*4');
    flag = fread(FID, 1, 'integer*4');
    status = fclose(FID);

    % on verifie que le flag vaut bien 1 cette fois-ci
    if flag ~= 1
        fprintf(1, '\n Il y a un probleme dans le format du fichier : le flag est different de 1\n');
        return
    end
end


% on lit toutes les metadonnees
FID = fopen([dir_complet,'/',nom_fichier(1,:)], 'r',type_endian);

poub            = fread(FID, 1, 'integer*4');
flag            = fread(FID, 1, 'integer*4');
nx              = fread(FID, 1, 'integer*4');
ny              = fread(FID, 1, 'integer*4');
nz              = fread(FID, 1, 'integer*4');
lx              = fread(FID, 1, 'real*8');
ly              = fread(FID, 1, 'real*8');
lz              = fread(FID, 1, 'real*8');
dt              = fread(FID, 1, 'real*8');
truncate        = fread(FID, 1, 'integer*4');
type_trunc      = fread(FID, 1, 'integer*4');
rtrunc_x        = fread(FID, 1, 'real*8');
rtrunc_y        = fread(FID, 1, 'real*8');
rtrunc_z        = fread(FID, 1, 'real*8');
nu              = fread(FID, 1, 'real*8');
stratification  = fread(FID, 1, 'integer*4');
xns             = fread(FID, 1, 'real*8');
schm            = fread(FID, 1, 'real*8');
omega2          = fread(FID, 1, 'real*8');
perturb        = fread(FID, 1, 'integer*4');
lin             = fread(FID, 1, 'integer*4');
poub            = fread(FID, 1, 'integer*4');
status = fclose(FID);


% on affiche quelques informations sur la simulation
fprintf(1, '\n Dimensions du probleme: %i * %i * %i \n', nx, ny, nz);
fprintf(1, '\n Dimensions physiques de la boite: %f * %f * %f \n', lx, ly, lz);

if (stratification == 0)
    freq_brunt = 0;
else
    freq_brunt = xns;
end

fprintf(1, '\n Stratification: %f \n', freq_brunt);

if (perturb==0)
    texte = ['non perturbatif'];
else
    if (lin==0) then
        texte = ['perturbatif/non lineaire'];
    else
        texte = ['perturbatif/lineaire'];
    end
end


% on determine les nombres d'ondes suivant kx et kz.
% en kx, on va de 0  kxmax (kxmax+1 modes en tout).
kxmax = floor(nx/2);
kx = linspace(0, kxmax, kxmax+1)*2*pi/lx;

nz = floor(nz/2);
kz = zeros(1,nz);
kz(1:nz+1) = linspace(0, nz, nz+1)*2*pi/lz;
kz(nz+2:nz) = (linspace(nz+1, nz-1, nz-nz-1)-nz)*2*pi/lz;


% on cre la grille des points de colocation
X = linspace(0, lx-lx/nx, nx);
Y = linspace(0, ly-ly/ny, ny);
Z = linspace(0, lz-lz/nz, nz);


% on lit les donnees dans le dernier fichier enregistre
FID = fopen([dir_complet,'/',nom_fichier(nb_fichiers,:)], 'r',type_endian);

% on lit toutes les metadonnees d'un coup "comme si" c'tait des entiers de 4 octets mme si ce n'est pas vrai,
% l'important est que le nombre d'octets soit respecte
poub = fread(FID, 33, 'integer*4');

poub = fread(FID, 1, 'integer*4');
instant = fread(FID, 1, 'real*8');
poub = fread(FID, 2, 'integer*4');
Velo_X = fread(FID, nx*ny*nz, 'real*8');
poub = fread(FID, 2, 'integer*4');
Velo_Y = fread(FID, nx*ny*nz, 'real*8');
poub = fread(FID, 2, 'integer*4');
Velo_Z = fread(FID, nx*ny*nz, 'real*8');
poub = fread(FID, 2, 'integer*4');
Rho = fread(FID, nx*ny*nz, 'real*8');
poub = fread(FID, 2, 'integer*4');
Vort_X = fread(FID, nx*ny*nz, 'real*8');
poub = fread(FID, 2, 'integer*4');
Vort_Y = fread(FID, nx*ny*nz, 'real*8');
poub = fread(FID, 2, 'integer*4');
Vort_Z = fread(FID, nx*ny*nz, 'real*8');

status = fclose(FID);

Velo_X = reshape(Velo_X, [nx,ny,nz]);
Velo_Y = reshape(Velo_Y, [nx,ny,nz]);
Velo_Z = reshape(Velo_Z, [nx,ny,nz]);
Rho    = reshape(Rho,    [nx,ny,nz]);
Vort_X = reshape(Vort_X, [nx,ny,nz]);
Vort_Y = reshape(Vort_Y, [nx,ny,nz]);
Vort_Z = reshape(Vort_Z, [nx,ny,nz]);


% on affiche le mode global correspondant au dernier instant enregistre
if mode_affichage == 1
    
    % on determine selon quel plan effectuer la coupe
    NZ_plot = 1;
    
    figure        
    if type_graphique==1
        contour(X,Y,squeeze(Vort_Z(:,:,NZ_plot))',20);
        colorbar;
    else
        pcolor(X,Y,squeeze(Vort_Z(:,:,NZ_plot))');
        shading flat,
    end
    
    xlabel('x');
    ylabel('y');
    axis square;
    title({['Vorticite verticale  t=', num2str(instant)]; ['Nb_points=', num2str(nx), 'x', num2str(ny), 'x', num2str(nz), '  L=', num2str(lx), 'x', num2str(ly), 'x', num2str(lz), '  dt=',num2str(dt), '  nu=',num2str(nu),'  N=', num2str(freq_brunt), '  ', texte]},'Interpreter','none');

% on affiche tous les modes kz par kz correspondant au dernier instant enregistre
else
            
    if mode_affichage==2
        liste_kz = 1:nz+1;
    end
    
    nb_graphiques = size(liste_kz,2);
        
    Nb_plot_par_figure = subplot_par_figure(1)*subplot_par_figure(2);    
    nb_figure = ceil(nb_graphiques/Nb_plot_par_figure)
        
    % utile pour afficher le mode kz par kz
    Vort_Z_fft = fft(Vort_Z,[],3);
    
    for ind_figure = 1:nb_figure        
        figure
            
        for it=(ind_figure-1)*Nb_plot_par_figure+1:min(ind_figure*Nb_plot_par_figure, nb_graphiques)            
            subplot(subplot_par_figure(1), subplot_par_figure(2), it - (ind_figure-1)*Nb_plot_par_figure );   
                       
            if type_graphique==1
                contour(X,Y,squeeze(real(Vort_Z_fft(:,:,liste_kz(it))))',20);
                colorbar;
            else
                pcolor(X,Y,squeeze(real(Vort_Z_fft(:,:,liste_kz(it))))');
                shading flat,
            end
            
            xlabel('x');
            ylabel('y');
            axis square;
            
            title({['Vorticite verticale   t=', num2str(instant), '  kz=',num2str(kz(liste_kz(it)))]; ['Nb_points=', num2str(nx), 'x', num2str(ny), 'x', num2str(nz), '  L=', num2str(lx), 'x', num2str(ly), 'x', num2str(lz), '  dt=',num2str(dt), '  nu=',num2str(nu),'  N=', num2str(freq_brunt), '  ', texte]},'Interpreter','none');
                    
        end
    end    
end
