% We use as input file the result of a perturbative linear simulation made with only one single mode.
% We write an ouput file with a velocity file corresponding to the mode found in the 2D linear simulation
% but with a  


% This script takes a 2D base state and adds a 3D linear perturbation to build a 3D velocity.
% This initial velocity can be used to start a non-perturbative simulation.


if strcmp('PCWIN', computer)
	ls('.');
else
	system(['ls -t ', '.']);
end

perturbation_file = input('velocity file to use: ', 's');
amplitude = input('perturbation amplitude: ');
nz_final = input('nombre de modes en z: ');

% on commence par essayer en little-endian (PC)
type_endian = 'ieee-le';
FID = fopen(perturbation_file, 'r',type_endian);
poub = fread(FID, 1, 'integer*4');
flag = fread(FID, 1, 'integer*4');
status = fclose(FID);

% si le flag est different de 1, on essaye le big-endian (SGI, NEC, IBM)
if flag ~= 1
    type_endian = 'ieee-be';
    FID = fopen(perturbation_file, 'r',type_endian);
    poub = fread(FID, 1, 'integer*4');
    flag = fread(FID, 1, 'integer*4');
    status = fclose(FID);

    % on verifie que le flag vaut bien 1 cette fois-ci
    if flag ~= 1
        fprintf(1, '\n Il y a un probleme dans le format du fichier : le flag est different de 1\n');
        return
    end
end


% on lit toutes les metadonnees
fprintf('Reading of the velocity file...');

FID = fopen(perturbation_file, 'r',type_endian);
poub            = fread(FID, 1, 'integer*4');
flag            = fread(FID, 1, 'integer*4');
nx              = fread(FID, 1, 'integer*4');
ny              = fread(FID, 1, 'integer*4');
nz              = fread(FID, 1, 'integer*4');
lx              = fread(FID, 1, 'real*8');
ly              = fread(FID, 1, 'real*8');
lz              = fread(FID, 1, 'real*8');
dt              = fread(FID, 1, 'real*8');
truncate        = fread(FID, 1, 'integer*4');
type_trunc      = fread(FID, 1, 'integer*4');
rtrunc_x        = fread(FID, 1, 'real*8');
rtrunc_y        = fread(FID, 1, 'real*8');
rtrunc_z        = fread(FID, 1, 'real*8');
nu              = fread(FID, 1, 'real*8');
stratification  = fread(FID, 1, 'integer*4');
xns             = fread(FID, 1, 'real*8');
schm            = fread(FID, 1, 'real*8');
omega2          = fread(FID, 1, 'real*8');
perturb         = fread(FID, 1, 'integer*4');
lin             = fread(FID, 1, 'integer*4');
poub            = fread(FID, 1, 'integer*4');


% we read the perturbation field
poub = fread(FID, 1, 'integer*4');
instant = fread(FID, 1, 'real*8');
poub = fread(FID, 2, 'integer*4');
Velo_X = fread(FID, nx*ny*nz, 'real*8');
poub = fread(FID, 2, 'integer*4');
Velo_Y = fread(FID, nx*ny*nz, 'real*8');
poub = fread(FID, 2, 'integer*4');
Velo_Z = fread(FID, nx*ny*nz, 'real*8');
poub = fread(FID, 2, 'integer*4');
Rho = fread(FID, nx*ny*nz, 'real*8');
poub = fread(FID, 2, 'integer*4');
Vort_X = fread(FID, nx*ny*nz, 'real*8');
poub = fread(FID, 2, 'integer*4');
Vort_Y = fread(FID, nx*ny*nz, 'real*8');
poub = fread(FID, 2, 'integer*4');
Vort_Z = fread(FID, nx*ny*nz, 'real*8');
poub = fread(FID, 1, 'integer*4');

% we read the base state
poub = fread(FID, 1, 'integer*4');
VBX = fread(FID, nx*ny, 'real*8');
VBY = fread(FID, nx*ny, 'real*8');
VBZ = fread(FID, nx*ny, 'real*8');
poub = fread(FID, 2, 'integer*4');
WBX = fread(FID, nx*ny, 'real*8');
WBY = fread(FID, nx*ny, 'real*8');
WBZ = fread(FID, nx*ny, 'real*8');
status = fclose(FID);
fprintf(' -> ok\n');

% we display some informations on the simulation
fprintf(1, 'Dimensions of the simulation: %i * %i * %i \n', nx, ny, nz);
fprintf(1, 'Physical dimensions of the simulation: %f * %f * %f \n', lx, ly, lz);

Velo_X = reshape(Velo_X, [nx,ny,nz]);
Velo_Y = reshape(Velo_Y, [nx,ny,nz]);
Velo_Z = reshape(Velo_Z, [nx,ny,nz]);
Rho    = reshape(Rho,    [nx,ny,nz]);
Vort_X = reshape(Vort_X, [nx,ny,nz]);
Vort_Y = reshape(Vort_Y, [nx,ny,nz]);
Vort_Z = reshape(Vort_Z, [nx,ny,nz]);

% on reordonne les tableaux
VBX = reshape(VBX, [nx,ny]);
VBY = reshape(VBY, [nx,ny]);
VBZ = reshape(VBZ, [nx,ny]);
WBX = reshape(WBX, [nx,ny]);
WBY = reshape(WBY, [nx,ny]);
WBZ = reshape(WBZ, [nx,ny]);


% we determine the ratio for the amplitude...
fprintf('Determination of the new velocity field...');
ratio = amplitude*max(max(abs(WBZ)))/max(max(max(abs(Vort_Z))));

ZZ = linspace(0, (nz_final-1)*lz/nz_final, nz_final);
KZ = 2*pi/lz;

% on imprime dans le fichier de sortie au format little-endian
fprintf('Writing of the new velocity field...');
% FID = fopen(['initial_velocity_big_endian_mode_zigzag=',num2str(amplitude)], 'w','ieee-be');
FID = fopen(['initial_velocity_big_endian_mode_zigzag=0.01_512x512x128_L=8.4x8.4x0.57'], 'w','ieee-be');



fwrite(FID, 124, 'integer*4');
fwrite(FID, 1, 'integer*4');
fwrite(FID, nx, 'integer*4');
fwrite(FID, ny, 'integer*4');
fwrite(FID, nz_final, 'integer*4');
fwrite(FID, lx, 'real*8');
fwrite(FID, ly, 'real*8');
fwrite(FID, lz, 'real*8');
fwrite(FID, dt, 'real*8');
fwrite(FID, truncate, 'integer*4');
fwrite(FID, type_trunc, 'integer*4');
fwrite(FID, rtrunc_x, 'real*8');
fwrite(FID, rtrunc_y, 'real*8');
fwrite(FID, rtrunc_z, 'real*8');
fwrite(FID, nu, 'real*8');
fwrite(FID, stratification, 'integer*4');
fwrite(FID, xns, 'real*8');
fwrite(FID, schm, 'real*8');
fwrite(FID, omega2, 'real*8');
fwrite(FID, perturb, 'integer*4');
fwrite(FID, lin, 'integer*4');
fwrite(FID, 124, 'integer*4');

fwrite(FID, 8, 'integer*4');
fwrite(FID, 0., 'real*8');
fwrite(FID, 8, 'integer*4');


temp_final = zeros(nx,ny,nz_final);

% we build the new velocity and vorticity
for iz=1:nz_final
	temp_final(:,:,iz) =  Velo_X(:,:,1)*cos(KZ*ZZ(iz));
end
fwrite(FID, nx*ny*nz_final*8, 'integer*4');
fwrite(FID, temp_final, 'real*8');
fwrite(FID, nx*ny*nz_final*8, 'integer*4');

% we print some fields to check if everything is correct
X = linspace(0, lx-lx/nx, nx);
Y = linspace(0, ly-ly/ny, ny);
Z = linspace(0, lz-lz/nz, nz);
figure(1)
contour(X,Y,temp_final(:,:,1))

for iz=1:nz_final
	temp_final(:,:,iz) =  Velo_Y(:,:,1)*cos(KZ*ZZ(iz));
end
fwrite(FID, nx*ny*nz_final*8, 'integer*4');
fwrite(FID, temp_final, 'real*8');
fwrite(FID, nx*ny*nz_final*8, 'integer*4');

% we print some fields to check if everything is correct
figure(2)
contour(X,Y,temp_final(:,:,1))


for iz=1:nz_final
	temp_final(:,:,iz) =  -Velo_Z(:,:,1)*sin(KZ*ZZ(iz));
end
fwrite(FID, nx*ny*nz_final*8, 'integer*4');
fwrite(FID, temp_final, 'real*8');
fwrite(FID, nx*ny*nz_final*8, 'integer*4');


% we write a null density perturbation
temp_final =  zeros(nx,ny,nz_final);
fwrite(FID, nx*ny*nz_final*8, 'integer*4');
fwrite(FID, temp_final, 'real*8');
fwrite(FID, nx*ny*nz_final*8, 'integer*4');

% we write the vorticity
for iz=1:nz_final
	temp_final(:,:,iz) =  Vort_X(:,:,1)*cos(KZ*ZZ(iz));
end
fwrite(FID, nx*ny*nz_final*8, 'integer*4');
fwrite(FID, temp_final, 'real*8');
fwrite(FID, nx*ny*nz_final*8, 'integer*4');


for iz=1:nz_final
	temp_final(:,:,iz) =  Vort_Y(:,:,1)*cos(KZ*ZZ(iz));
end
fwrite(FID, nx*ny*nz_final*8, 'integer*4');
fwrite(FID, temp_final, 'real*8');
fwrite(FID, nx*ny*nz_final*8, 'integer*4');


for iz=1:nz_final
	temp_final(:,:,iz) =  Vort_Z(:,:,1)*cos(KZ*ZZ(iz));
end
fwrite(FID, nx*ny*nz_final*8, 'integer*4');
fwrite(FID, temp_final, 'real*8');
fwrite(FID, nx*ny*nz_final*8, 'integer*4');

% we print some fields to check if everything is correct
figure(4)
pcolor(X,Y,temp_final(:,:,1)');
shading flat;


clear temp_final

% we write a null base state
fwrite(FID, nx*ny*8*3, 'integer*4');
fwrite(FID, VBX, 'real*8');
fwrite(FID, VBY, 'real*8');
fwrite(FID, VBZ, 'real*8');
fwrite(FID, nx*ny*8*3, 'integer*4');

fwrite(FID, nx*ny*8*3, 'integer*4');
fwrite(FID, WBX, 'real*8');
fwrite(FID, WBY, 'real*8');
fwrite(FID, WBZ, 'real*8');
fwrite(FID, nx*ny*8*3, 'integer*4');

status = fclose(FID);
fprintf(' -> ok\n');

fprintf(' -> ok\n');

% we display the initial velocity
% fprintf('Plotting of the new velocity field...');

% we release memory
% clear Velo_X Velo_Y Velo_Z Rho Vort_X Vort_Y Vort_Z Velo_X_final Velo_Y_final Velo_Z_final Vort_X_final Vort_Y_final

% on cre la grille des points de colocation
% X = linspace(0, lx-lx/nx, nx);
% Y = linspace(0, ly-ly/ny, ny);
% Z = linspace(0, lz-lz/nz, nz);

% pmoy_v=mean(max(max(Vort_Z_final)));
% nmoy_v=-pmoy_v;

% p = patch(isosurface(Y,X,Z,Vort_Z_final,0.6*pmoy_v));
% isonormals(Y,X,Z,Vort_Z_final,p)
% set(p,'FaceAlpha',0.9,'FaceColor','red','EdgeColor','none');
% p2 = patch(isosurface(Y,X,Z,Vort_Z_final,0.05*pmoy_v));
% isonormals(Y,X,Z,Vort_Z_final,p2)
% set(p2,'FaceAlpha',0.15,'FaceColor',[255,251,140]/256,'EdgeColor','none');

% p3 = patch(isosurface(Y,X,Z,Vort_Z_final,0.6*nmoy_v));
% isonormals(Y,X,Z,Vort_Z_final,p3)
% set(p3,'FaceAlpha',0.9,'FaceColor','blue','EdgeColor','none');
% p4 = patch(isosurface(Y,X,Z,Vort_Z_final,0.05*nmoy_v));
% isonormals(Y,X,Z,Vort_Z_final,p4)
% set(p4,'FaceAlpha',0.15,'FaceColor',[130,186,212]/256,'EdgeColor','none');

% daspect([1 1 1])
% view(3);
% axis([Y(1) Y(end) X(1) X(end) Z(1) Z(end)])
% box on
% grid on
% camlight
% lighting gouraud

% title({['Vertical vorticity']; ['Nb_points=', num2str(nx), 'x', num2str(ny), 'x', num2str(nz), '  L=', num2str(lx), 'x', num2str(ly), 'x', num2str(lz)]},'Interpreter','none');
% fprintf(' -> ok\n');
