% ######################
% global_vars a renseigner
% ######################

% start and end (0 means the last file) of the recording sequence
first_file=1
last_file=0

% name of the movie file
name_movie = 'contrarotating.mov';
framerate = 2;
quality = 0.85;

% ######################
% on touche plus
% ######################

% noms des fichiers de donnees
if strcmp('PCWIN', computer)
	[poub,liste_fichiers] = system('dir /B');
else
	[poub,liste_fichiers] = system('ls ');
end

[start,finish] = regexpi(liste_fichiers,'velo_rho_vort.t=\d*\.\d*');

% initial_velocity_big_endian_mode_zigzag=0.01_512x512x256

nb_fichiers = size(start,2);

% we adjust the first and last file to process
if last_file == 0
    last_file=nb_fichiers;
end

clear nom_fichier
for i=1:nb_fichiers
    nom_fichier(i,:) = liste_fichiers(start(i):finish(i));
end

nom_fichier = sortrows(nom_fichier);
fichier = nom_fichier(1,:)

% we determine the type of binary data (little-endian, big-endian) with the file header

% we start with little-endian (PC)
type_endian = 'ieee-le';
FID = fopen(fichier, 'r',type_endian);
poub = fread(FID, 1, 'integer*4');
flag = fread(FID, 1, 'integer*4');
status = fclose(FID);

% if the flag is not 1, we try big-endian (SGI, NEC, IBM)
if flag ~= 1
    type_endian = 'ieee-be';
    FID = fopen(fichier, 'r',type_endian);
    poub = fread(FID, 1, 'integer*4');
    flag = fread(FID, 1, 'integer*4');
    status = fclose(FID);

    % we check again the value of the flag
    if flag ~= 1
        fprintf(1, '\n There is a problem with the format of the data file: the flag is not 1\n');
        return
    end
end


% we read the metadata
FID = fopen(fichier, 'r',type_endian);

poub            = fread(FID, 1, 'integer*4');
flag            = fread(FID, 1, 'integer*4');
nx              = fread(FID, 1, 'integer*4');
ny              = fread(FID, 1, 'integer*4');
nz              = fread(FID, 1, 'integer*4');
lx              = fread(FID, 1, 'real*8');
ly              = fread(FID, 1, 'real*8');
lz              = fread(FID, 1, 'real*8');
dt              = fread(FID, 1, 'real*8');
truncate        = fread(FID, 1, 'integer*4');
type_trunc      = fread(FID, 1, 'integer*4');
rtrunc_x        = fread(FID, 1, 'real*8');
rtrunc_y        = fread(FID, 1, 'real*8');
rtrunc_z        = fread(FID, 1, 'real*8');
nu              = fread(FID, 1, 'real*8');
stratification  = fread(FID, 1, 'integer*4');
xns             = fread(FID, 1, 'real*8');
schm            = fread(FID, 1, 'real*8');
omega2          = fread(FID, 1, 'real*8');
perturb         = fread(FID, 1, 'integer*4');
lin             = fread(FID, 1, 'integer*4');
poub            = fread(FID, 1, 'integer*4');

status = fclose(FID);

% we display some informations about the simulation
fprintf(1, '\n Dimensions of the simulation: %i * %i * %i \n', nx, ny, nz);
fprintf(1, '\n Physical dimensions of the box: %f * %f * %f \n', lx, ly, lz);

if (stratification == 0)
    freq_brunt = 0;
else
    freq_brunt = xns;
end

fprintf(1, '\n Stratification: %f \n', freq_brunt);

if (perturb==0)
    texte = ['non perturbative'];
else
    if (lin==0) then
        texte = ['perturbative/non linear\n'];
    else
        texte = ['perturbative/linear\n'];
    end
end

% on cre la grille des points de colocation
X = linspace(0, lx-lx/nx, nx);
Y = linspace(0, ly-ly/ny, ny);
Z = linspace(0, lz-lz/nz, nz);

scrsz = get(0,'ScreenSize');
figure('Position',[100 100 scrsz(3)*0.8 scrsz(4)*0.8])

MakeQTMovie('start',name_movie)
MakeQTMovie('framerate',framerate)
MakeQTMovie('quality',quality)

fprintf('\n Plotting...\n');

% we create the working arrays
Vort_Z = zeros(nx,ny,nz);

for it=first_file:last_file

    fprintf(1, ' Num of frame: %i/%i \n', it,nb_fichiers);

    clf

    % on lit les donnees dans le dernier fichier enregistre
    FID = fopen(nom_fichier(it,:),'r',type_endian);

    % on lit toutes les metadonnees d'un coup
    fseek(FID, 4*34, 'bof');
    instant = fread(FID, 1, 'real*8');

    % on va directement lire la vorticite verticale
    fseek(FID, 48*4+8+6*8*nx*ny*nz, 'bof');
    Vort_Z = fread(FID, nx*ny*nz, 'real*8');

    status = fclose(FID);

    Vort_Z = reshape(Vort_Z, [nx,ny,nz]);

    pmoy_v=mean(max(max(Vort_Z)));
    nmoy_v=-pmoy_v;

    p = patch(isosurface(Y,X,Z,Vort_Z,0.6*pmoy_v));
    isonormals(Y,X,Z,Vort_Z,p)
    set(p,'FaceAlpha',0.9,'FaceColor','red','EdgeColor','none');
    p2 = patch(isosurface(Y,X,Z,Vort_Z,0.05*pmoy_v));
    isonormals(Y,X,Z,Vort_Z,p2)
    set(p2,'FaceAlpha',0.15,'FaceColor',[255,251,140]/256,'EdgeColor','none');

    p3 = patch(isosurface(Y,X,Z,Vort_Z,0.6*nmoy_v));
    isonormals(Y,X,Z,Vort_Z,p3)
    set(p3,'FaceAlpha',0.9,'FaceColor','blue','EdgeColor','none');
    p4 = patch(isosurface(Y,X,Z,Vort_Z,0.05*nmoy_v));
    isonormals(Y,X,Z,Vort_Z,p4)
    set(p4,'FaceAlpha',0.15,'FaceColor',[130,186,212]/256,'EdgeColor','none');

    daspect([1 1 1])
    view(3);
    axis([Y(1) Y(end) X(1) X(end) Z(1) Z(end)])
    box on
    grid on
    camlight
    lighting gouraud

    title({['Vertical vorticity    t=', num2str(instant), '    Frame=',num2str(it),'/',num2str(nb_fichiers)]; ['Nb_points=', num2str(nx), 'x', num2str(ny), 'x', num2str(nz), '  L=', num2str(lx), 'x', num2str(ly), 'x', num2str(lz), '  dt=',num2str(dt), '  nu=',num2str(nu),'  N=', num2str(freq_brunt), '  ', texte]},'Interpreter','none');

    MakeQTMovie('addfigure');

end

MakeQTMovie('finish')
MakeQTMovie('cleanup');
