# @ job_name = io_stride
# @ shell = /bin/ksh
# @ output = $(job_name).$(jobid)
# @ error =  $(job_name).$(jobid)
# @ cpu_limit = 1:00:00
# @ data_limit = 4Gb
# @ queue

# we indicate where the velocity files are stores on gaya
dir_save_gaya="/u/rech/bll/rbll200/NS3D/ns3d_contrarotating_256x256x640_L=2.1x2.1x5.7_Dt=0.004_nu=1E-4_N=12._brodie_12-12-06_12h32_pid7848"

# dimensions of the velocity files and the strides along each directions
nx=256
ny=256
nz=640
str_x=2
str_y=2
str_z=2

#____________________________________________________________
#
#     DO NOT MODIFY BELOW!
#____________________________________________________________
#

printf "\nTemp directory: $TMPDIR\n"
cp io_stride.F90 $TMPDIR

cd $TMPDIR

# we change the dimensions in the source file
sed -e "s/integer, parameter :: nx=.*/integer, parameter :: nx=$nx/" \
    -e "s/integer, parameter :: ny=.*/integer, parameter :: ny=$ny/" \
    -e "s/integer, parameter :: nz=.*/integer, parameter :: nz=$nz/" \
    -e "s/integer, parameter :: str_x=.*/integer, parameter :: str_x=$str_x/" \
    -e "s/integer, parameter :: str_y=.*/integer, parameter :: str_y=$str_y/" \
    -e "s/integer, parameter :: str_z=.*/integer, parameter :: str_z=$str_z/" \
    io_stride.F90 > io_stride.F90_bis

mv io_stride.F90_bis io_stride.F90

# compilation
printf "\nCompilation of the Fortran code...\n"
xlf_r -qfree=F90 -qsuffix=f=F90 -qautodbl=dbl4 -qintsize=8 io_stride.F90 -o io_stride
chmod 744 io_stride

# useful to store the strided files on Gaya
nxp=`expr $nx - 1`
nxp=`expr $nxp / $str_x + 1`
nyp=`expr $ny - 1`
nyp=`expr $nyp / $str_y + 1`
nzp=`expr $nz - 1`
nzp=`expr $nzp / $str_z + 1`

# we get the list of the original velocity files
printf "\nGetting the list of the original files from Gaya...\n"
ssh -x rbll200@gaya.idris.fr "cd $dir_save_gaya ; ls -1 velo_rho_vort.t=* > liste_fichiers.txt"
mfget        $dir_save_gaya/liste_fichiers.txt .

# Copy of each file...
printf "\nCopy of each file...\n"
for name in `cat liste_fichiers.txt`; do
	printf "\n    velocity file: $name";
	mfget        $dir_save_gaya/$name;
	echo $name | ./io_stride;
	mv stride_$name $name;
	mfput $name $dir_save_gaya/stride_${nxp}x${nyp}x${nzp}/$name;
	rm -rf $name;
done

mfput io_stride.F90 io_stride liste_fichiers.txt $dir_save_gaya/stride_${nxp}x${nyp}x${nzp}

exit
